Struct google_cloudtasks2_beta2::AcknowledgeTaskRequest
[−]
[src]
pub struct AcknowledgeTaskRequest {
pub schedule_time: Option<String>,
}Request message for acknowledging a task using CloudTasks.AcknowledgeTask.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
schedule_time: Option<String>
Required.
The task's current schedule time, available in the Task.schedule_time returned in PullTasksResponse.tasks or CloudTasks.RenewLease. This restriction is to check that the caller is acknowledging the correct task.