Struct google_cloudtasks2_beta2::AppEngineHttpTarget
[−]
[src]
pub struct AppEngineHttpTarget {
pub app_engine_routing_override: Option<AppEngineRouting>,
}App Engine HTTP target.
The task will be delivered to the App Engine application hostname specified by its AppEngineHttpTarget and AppEngineHttpRequest. The documentation for AppEngineHttpRequest explains how the task's host URL is constructed.
Using AppEngineHttpTarget requires
appengine.applications.get
Google IAM permission for the project
and the following scope:
https://www.googleapis.com/auth/cloud-platform
This type is not used in any activity, and only used as part of another schema.
Fields
app_engine_routing_override: Option<AppEngineRouting>
Overrides for the task-level app_engine_routing.
If set, AppEngineHttpTarget.app_engine_routing_override is used for all tasks in the queue, no matter what the setting is for the task-level app_engine_routing.