Struct google_cloudtasks2_beta2::ListQueuesResponse
[−]
[src]
pub struct ListQueuesResponse {
pub next_page_token: Option<String>,
pub queues: Option<Vec<Queue>>,
}Response message for CloudTasks.ListQueues.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations queues list projects (response)
Fields
next_page_token: Option<String>
A token to retrieve next page of results.
To return the next page of results, call CloudTasks.ListQueues with this value as the ListQueuesRequest.page_token.
If the next_page_token is empty, there are no more results.
The page token is valid for only 2 hours.
queues: Option<Vec<Queue>>
The list of queues.