Struct google_cloudtasks2_beta2::PauseQueueRequest [] [src]

pub struct PauseQueueRequest { /* fields omitted */ }

Request message for CloudTasks.PauseQueue.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).