Struct google_cloudtasks2_beta2::PullMessage[][src]

pub struct PullMessage {
    pub tag: Option<String>,
    pub payload: Option<String>,
}

The pull message contains data that can be used by the caller of CloudTasks.PullTasks to process the task.

This proto can only be used for tasks in a queue which has Queue.pull_target set.

This type is not used in any activity, and only used as part of another schema.

Fields

The task's tag.

Tags allow similar tasks to be processed in a batch. If you label tasks with a tag, your task worker can pull tasks with the same tag using PullTasksRequest.filter. For example, if you want to aggregate the events associated with a specific user once a day, you could tag tasks with the user ID.

The task's tag can only be set when the task is created.

The tag must be less than 500 bytes.

A data payload consumed by the task worker to execute the task.