Struct google_cloudtasks2_beta2::Queue
[−]
[src]
pub struct Queue {
pub name: Option<String>,
pub app_engine_queue_config: Option<AppEngineQueueConfig>,
pub app_engine_http_target: Option<AppEngineHttpTarget>,
pub pull_target: Option<PullTarget>,
pub pull_queue_config: Option<PullQueueConfig>,
pub purge_time: Option<String>,
pub throttle_config: Option<ThrottleConfig>,
pub queue_state: Option<String>,
pub retry_config: Option<RetryConfig>,
}A queue is a container of related tasks. Queues are configured to manage how those tasks are dispatched. Configurable properties include rate limits, retry options, target types, and others.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations queues pause projects (response)
- locations queues resume projects (response)
- locations queues patch projects (request|response)
- locations queues create projects (request|response)
- locations queues get projects (response)
- locations queues purge projects (response)
Fields
name: Option<String>
The queue name.
The queue name must have the following format:
projects/PROJECT_ID/locations/LOCATION_ID/queues/QUEUE_ID
PROJECT_IDcan contain uppercase and lowercase letters, numbers, hyphens, colons, and periods; that is, it must match the regular expression:[a-zA-Z\\d-:\\.]+.QUEUE_IDcan contain uppercase and lowercase letters, numbers, and hyphens; that is, it must match the regular expression:[a-zA-Z\\d-]+. The maximum length is 100 characters.
Caller-specified and required in CreateQueueRequest, after which it becomes output only.
app_engine_queue_config: Option<AppEngineQueueConfig>
Deprecated. Use Queue.app_engine_http_target.
app_engine_http_target: Option<AppEngineHttpTarget>
App Engine HTTP target.
An App Engine queue is a queue that has an AppEngineHttpTarget.
pull_target: Option<PullTarget>
Pull target.
A pull queue is a queue that has a PullTarget.
pull_queue_config: Option<PullQueueConfig>
Deprecated. Use Queue.pull_target.
purge_time: Option<String>
Output only.
The last time this queue was purged. All tasks that were created before this time were purged.
A queue can be purged using CloudTasks.PurgeQueue, the App Engine Task Queue SDK, or the Cloud Console.
Purge time will be truncated to the nearest microsecond. Purge time will be zero if the queue has never been purged.
throttle_config: Option<ThrottleConfig>
Config for throttling task dispatches.
queue_state: Option<String>
Output only.
The state of the queue.
queue_state can only be changed by called
CloudTasks.PauseQueue, CloudTasks.ResumeQueue, or uploading
queue.yaml.
CloudTasks.UpdateQueue cannot be used to change queue_state.
retry_config: Option<RetryConfig>
Settings that determine the retry behavior.
- For tasks created using Cloud Tasks: the queue-level retry settings apply to all tasks in the queue that were created using Cloud Tasks. Retry settings cannot be set on individual tasks.
- For tasks created using the App Engine SDK: the queue-level retry settings apply to all tasks in the queue which do not have retry settings explicitly set on the task and were created by the App Engine SDK. See App Engine documentation.