Struct google_cloudtasks2_beta2::RetryConfig
[−]
[src]
pub struct RetryConfig {
pub max_attempts: Option<i32>,
pub min_backoff: Option<String>,
pub task_age_limit: Option<String>,
pub max_doublings: Option<i32>,
pub max_backoff: Option<String>,
pub unlimited_attempts: Option<bool>,
}Retry config.
These settings determine retry behavior.
If a task does not complete successfully, meaning that an acknowledgement is not received from the handler before the deadline, then it will be retried with exponential backoff according to the settings in RetryConfig.
This type is not used in any activity, and only used as part of another schema.
Fields
max_attempts: Option<i32>
The maximum number of attempts for a task.
Cloud Tasks will attempt the task max_attempts times (that
is, if the first attempt fails, then there will be
max_attempts - 1 retries). Must be > 0.
min_backoff: Option<String>
The minimum amount of time to wait before retrying a task after it fails.
- For App Engine queues, this field is 0.1 seconds by default.
- For pull queues, this field is output only and always 0.
min_backoff will be truncated to the nearest second.
task_age_limit: Option<String>
If positive, task_age_limit specifies the time limit for retrying a failed task, measured from when the task was first run. If specified with RetryConfig.max_attempts, the task will be retried until both limits are reached.
If zero, then the task age is unlimited. This field is zero by default.
task_age_limit will be truncated to the nearest second.
max_doublings: Option<i32>
The maximum number of times that the interval between failed task retries will be doubled before the increase becomes constant. The constant is: 2**(max_doublings - 1) * RetryConfig.min_backoff.
- For App Engine queues, this field is 16 by default.
- For pull queues, this field is output only and always 0.
max_backoff: Option<String>
The maximum amount of time to wait before retrying a task after it fails. The default is 1 hour.
- For App Engine queues, this field is 1 hour by default.
- For pull queues, this field is output only and always 0.
max_backoff will be truncated to the nearest second.
unlimited_attempts: Option<bool>
If true, then the number of attempts is unlimited.