Struct google_cloudtasks2_beta2::ThrottleConfig
[−]
[src]
pub struct ThrottleConfig {
pub max_tasks_dispatched_per_second: Option<f64>,
pub max_burst_size: Option<i32>,
pub max_outstanding_tasks: Option<i32>,
}Throttle config.
These settings determine the throttling behavior.
This type is not used in any activity, and only used as part of another schema.
Fields
max_tasks_dispatched_per_second: Option<f64>
The maximum rate at which tasks are dispatched from this queue.
The maximum allowed value is 500.
- For App Engine queues, this field is 1 by default.
- For pull queues, this field is output only and always 10,000.
This field has the same meaning as rate in queue.yaml.
max_burst_size: Option<i32>
Output only.
The max burst size limits how fast the queue is processed when many tasks are in the queue and the rate is high. This field allows the queue to have a high rate so processing starts shortly after a task is enqueued, but still limits resource usage when many tasks are enqueued in a short period of time.
- For App Engine queues, if ThrottleConfig.max_tasks_dispatched_per_second is 1, this field is 10; otherwise this field is ThrottleConfig.max_tasks_dispatched_per_second / 5.
- For pull queues, this field is output only and always 10,000.
Note: For App Engine queues that were created through
queue.yaml/xml, max_burst_size might not have the same
settings as specified above; CloudTasks.UpdateQueue can be
used to set max_burst_size only to the values specified above.
This field has the same meaning as bucket_size in queue.yaml.
max_outstanding_tasks: Option<i32>
The maximum number of outstanding tasks that Cloud Tasks allows to be dispatched for this queue. After this threshold has been reached, Cloud Tasks stops dispatching tasks until the number of outstanding requests decreases.
The maximum allowed value is 5,000.
- For App Engine queues, this field is 10 by default.
- For pull queues, this field is output only and always -1, which indicates no limit.
This field has the same meaning as max_concurrent_requests in queue.yaml.