Struct google_cloudtasks2_beta2::AcknowledgeTaskRequest [−][src]
Request message for acknowledging a task using AcknowledgeTask.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
schedule_time: Option<String>
Required.
The task's current schedule time, available in the schedule_time returned by LeaseTasks response or RenewLease response. This restriction is to ensure that your worker currently holds the lease.