[−][src]Struct google_cloudtasks2_beta2::AttemptStatus
The status of a task attempt.
This type is not used in any activity, and only used as part of another schema.
Fields
schedule_time: Option<String>Output only. The time that this attempt was scheduled.
schedule_time will be truncated to the nearest microsecond.
dispatch_time: Option<String>Output only. The time that this attempt was dispatched.
dispatch_time will be truncated to the nearest microsecond.
response_time: Option<String>Output only. The time that this attempt response was received.
response_time will be truncated to the nearest microsecond.
response_status: Option<Status>Output only. The response from the target for this attempt.
If the task has not been attempted or the task is currently running then the response status is unset.